Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(190)

Unified Diff: webrtc/modules/audio_processing/test/protobuf_utils.h

Issue 1694423002: Replace scoped_ptr with unique_ptr in webrtc/modules/audio_processing/test/ (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/modules/audio_processing/test/protobuf_utils.h
diff --git a/webrtc/modules/audio_processing/test/protobuf_utils.h b/webrtc/modules/audio_processing/test/protobuf_utils.h
index 406f128b3ba717cbbca510011c40569eed3c929f..3ab90b7761ac6dab4d47f08d6f852d81b397b440 100644
--- a/webrtc/modules/audio_processing/test/protobuf_utils.h
+++ b/webrtc/modules/audio_processing/test/protobuf_utils.h
@@ -11,14 +11,15 @@
#ifndef WEBRTC_MODULES_AUDIO_PROCESSING_TEST_PROTOBUF_UTILS_H_
#define WEBRTC_MODULES_AUDIO_PROCESSING_TEST_PROTOBUF_UTILS_H_
-#include "webrtc/base/scoped_ptr.h"
+#include <memory>
+
#include "webrtc/modules/audio_processing/debug.pb.h"
namespace webrtc {
// Allocates new memory in the scoped_ptr to fit the raw message and returns the
// number of bytes read.
-size_t ReadMessageBytesFromFile(FILE* file, rtc::scoped_ptr<uint8_t[]>* bytes);
+size_t ReadMessageBytesFromFile(FILE* file, std::unique_ptr<uint8_t[]>* bytes);
// Returns true on success, false on error or end-of-file.
bool ReadMessageFromFile(FILE* file, ::google::protobuf::MessageLite* msg);
« no previous file with comments | « webrtc/modules/audio_processing/test/process_test.cc ('k') | webrtc/modules/audio_processing/test/protobuf_utils.cc » ('j') | no next file with comments »
@@ -11,14 +11,15 @@
#include "webrtc/modules/audio_processing/debug.pb.h"
namespace webrtc {
-// Allocates new memory in the scoped_ptr to fit the raw message and returns the
+// Allocates new memory in the unique_ptr to fit the raw message and returns the
// number of bytes read.

Powered by Google App Engine
This is Rietveld 408576698